@@ -3,11 +3,10 @@
      Copyright (C) 2001  CCLRC, Peter Briggs
      Copyright (C) 2007 Morten Kjeldgaard
 
-     This library is free software; you can redistribute it and/or
+     This library is free software: you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
-     License as published by the Free Software Foundation; either
-     version 2.1 of the License, or (at your option) any later
-     version.
+     License as published by the Free Software Foundation, either
+     version 3 of the License, or (at your option) any later version.
 
      This library is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,9 +14,8 @@
      Lesser General Public License for more details.
 
      You should have received a copy of the GNU Lesser General Public
-     License along with this library; if not, write to the Free
-     Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-     Boston, MA 02110-1301 USA
+     License along with This library.  If not, see
+     <http://www.gnu.org/licenses/>.
 
 */
 
@@ -44,7 +42,6 @@
 char *ccp4_prog_vers(const char *progvers) 
 {
   static char programversion[MAXLEN_PROGVERSION]="";
-  int         i;
 
   if (progvers) {
     strncpy(programversion, progvers, MAXLEN_PROGVERSION);
