@@ -2,11 +2,10 @@
      cmtzlib.h: header file for cmtzlib.c
      Copyright (C) 2001  CCLRC, Martyn Winn
 
-     This library is free software; you can redistribute it and/or
+     This library is free software: you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
-     License as published by the Free Software Foundation; either
-     version 2.1 of the License, or (at your option) any later
-     version.
+     License as published by the Free Software Foundation, either
+     version 3 of the License, or (at your option) any later version.
 
      This library is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +13,8 @@
      Lesser General Public License for more details.
 
      You should have received a copy of the GNU Lesser General Public
-     License along with this library; if not, write to the Free
-     Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-     Boston, MA 02110-1301 USA
+     License along with This library.  If not, see
+     <http://www.gnu.org/licenses/>.
 
 */
 
@@ -190,6 +188,12 @@ int MtzWrefl(CCP4File *fileout, int ncol, float *refldata);
  */
 int MtzDeleteRefl(MTZ *mtz, int iref);
 
+/** Position input file at start of reflections. Useful if you need
+ * to read the reflections a second time.
+ * @param mtz pointer to MTZ struct.
+ */
+void MtzRewdInput(MTZ *mtz);
+
 /**** Memory allocation ****/
 
 /** Allocates memory for an MTZ header structure. The structure can
