@@ -2,11 +2,10 @@
      ccp4_diskio_f.c FORTRAN API for file i/o.
      Copyright (C) 2002  CCLRC, Charles Ballard and Martyn Winn
 
-     This library is free software; you can redistribute it and/or
+     This library is free software: you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
-     License as published by the Free Software Foundation; either
-     version 2.1 of the License, or (at your option) any later
-     version.
+     License as published by the Free Software Foundation, either
+     version 3 of the License, or (at your option) any later version.
 
      This library is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +13,8 @@
      Lesser General Public License for more details.
 
      You should have received a copy of the GNU Lesser General Public
-     License along with this library; if not, write to the Free
-     Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-     Boston, MA 02110-1301 USA
+     License along with This library.  If not, see
+     <http://www.gnu.org/licenses/>.
 */
 
 /** @page diskio_f_page Fortran API for low level input/output. 
@@ -107,7 +105,7 @@ FORTRAN_SUBR ( QOPEN, qopen,
     (int *iunit, fpstr lognam, int lognam_len, fpstr atbuta, int atbuta_len))
 {
   char *atbut2, *temp_lognam, *fname;
-  int istat;
+  int istat = 0;
 
   atbut2 = ccp4_FtoCString(FTN_STR(atbuta), FTN_LEN(atbuta));
   
@@ -380,12 +378,13 @@ FORTRAN_SUBR ( QREAD, qread,
     (int *iunit, uint8 *buffer, int *nitems, int *result))
 {
   *result = 0;
-  if ( ccp4_file_read (_ioChannels[*iunit]->iobj, buffer, *nitems) != *nitems) 
+  if ( ccp4_file_read (_ioChannels[*iunit]->iobj, buffer, *nitems) != *nitems) {
     if ( ccp4_file_feof(_ioChannels[*iunit]->iobj) ) 
       *result = -1;
     else 
       ccp4_signal(CCP4_ERRLEVEL(4) | CCP4_ERRNO(CIO_ReadFail),
 		  "QREAD", NULL);
+  }
 }
 
 /**
@@ -408,12 +407,13 @@ FORTRAN_SUBR ( QREADI, qreadi,
     (int *iunit, uint8* buffer, int *nitems, int *result))
     {
   *result = 0;
-  if ( ccp4_file_readint (_ioChannels[*iunit]->iobj, buffer, *nitems) != *nitems) 
+  if ( ccp4_file_readint (_ioChannels[*iunit]->iobj, buffer, *nitems) != *nitems) {
     if ( ccp4_file_feof(_ioChannels[*iunit]->iobj) ) 
       *result = -1;
     else 
       ccp4_signal(CCP4_ERRLEVEL(4) | CCP4_ERRNO(CIO_ReadFail),
 		  "QREADI", NULL);
+  }
 }
 
 /**
@@ -436,12 +436,13 @@ FORTRAN_SUBR ( QREADI2, qreadi2,
     (int *iunit, uint8* buffer, int *nitems, int *result))
     {
   *result = 0;
-  if ( ccp4_file_readshort (_ioChannels[*iunit]->iobj, buffer, *nitems) != *nitems) 
+  if ( ccp4_file_readshort (_ioChannels[*iunit]->iobj, buffer, *nitems) != *nitems) {
     if ( ccp4_file_feof(_ioChannels[*iunit]->iobj) ) 
       *result = -1;
     else 
       ccp4_signal(CCP4_ERRLEVEL(4) | CCP4_ERRNO(CIO_ReadFail),
 		  "QREADI2", NULL);
+  }
 }
 
 /**
@@ -464,12 +465,13 @@ FORTRAN_SUBR ( QREADR, qreadr,
     (int *iunit, uint8* buffer, int *nitems, int *result))
     {
   *result = 0;
-  if ( ccp4_file_readfloat (_ioChannels[*iunit]->iobj, buffer, *nitems) != *nitems) 
+  if ( ccp4_file_readfloat (_ioChannels[*iunit]->iobj, buffer, *nitems) != *nitems) {
     if ( ccp4_file_feof(_ioChannels[*iunit]->iobj) ) 
       *result = -1;
     else 
       ccp4_signal(CCP4_ERRLEVEL(4) | CCP4_ERRNO(CIO_ReadFail),
 		  "QREADR", NULL);
+  }
 }
 
 /**
@@ -492,12 +494,13 @@ FORTRAN_SUBR ( QREADQ, qreadq,
     (int *iunit, uint8* buffer, int *nitems, int *result))
     {
   *result = 0;
-  if ( ccp4_file_readcomp (_ioChannels[*iunit]->iobj, buffer, *nitems) != *nitems) 
+  if ( ccp4_file_readcomp (_ioChannels[*iunit]->iobj, buffer, *nitems) != *nitems) {
     if ( ccp4_file_feof(_ioChannels[*iunit]->iobj) ) 
       *result = -1;
     else 
       ccp4_signal(CCP4_ERRLEVEL(4) | CCP4_ERRNO(CIO_ReadFail),
 		  "QREADQ", NULL);
+  }
 }
 
 /**
@@ -706,10 +709,12 @@ FORTRAN_SUBR ( QQINQ, qqinq,
       log_name = strdup("diskio.dft"); 
     if (!(file_name = getenv(log_name)))
       file_name = log_name;
-    for ( *istrm = 1; *istrm == MAXFILES; *istrm++)
-      if (!strcmp(file_name,_ioChannels[*istrm]->iobj->name)) break;
+    for ( *istrm = 1; *istrm < MAXFILES; *istrm++) {
+      if (!strcmp(file_name,_ioChannels[*istrm]->iobj->name))
+	break;
+    }
   }
-  if (*istrm != MAXFILES) {
+  if (*istrm < MAXFILES) {
     *length = ccp4_file_length(_ioChannels[*istrm]->iobj);
     strncpy(FTN_STR(filename), _ioChannels[*istrm]->iobj->name,
                     MIN(strlen(_ioChannels[*istrm]->iobj->name), 
