@@ -2,11 +2,10 @@
      ccp4_general_f.c: Fortran API to ccp4_general.c.
      Copyright (C) 2001  CCLRC, Martyn Winn et al
 
-     This library is free software; you can redistribute it and/or
+     This library is free software: you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
-     License as published by the Free Software Foundation; either
-     version 2.1 of the License, or (at your option) any later
-     version.
+     License as published by the Free Software Foundation, either
+     version 3 of the License, or (at your option) any later version.
 
      This library is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +13,8 @@
      Lesser General Public License for more details.
 
      You should have received a copy of the GNU Lesser General Public
-     License along with this library; if not, write to the Free
-     Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-     Boston, MA 02110-1301 USA
+     License along with This library.  If not, see
+     <http://www.gnu.org/licenses/>.
 */
 
 /** @file ccp4_general_f.c
@@ -28,6 +26,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <math.h>
+#include <time.h>
 #include "ccp4_errno.h"
 #include "ccp4_fortran.h"
 #include "ccp4_parser.h"
@@ -453,8 +452,11 @@ FORTRAN_SUBR (GETELAPSED, getelapsed,(void) , (void) , (void))
   ccp4ProgramTime(0);
 }
 
-/*
-  Local variables:
-  mode: font-lock
-  End:
-*/
+/* wrapper for ccp4VerbosityLevel */
+FORTRAN_FUN ( int, CCP4VERBOSITYLEVEL, ccp4verbositylevel,
+              (int *level),
+              (int *level),
+              (int *level))
+{
+  return ( ccp4VerbosityLevel(*level) );
+}
