@@ -2,11 +2,10 @@
      cmaplib_f.c: Fortran API for accessing CCP4 map files
      Copyright (C) 2001  CCLRC, Charles Ballard
 
-     This library is free software; you can redistribute it and/or
+     This library is free software: you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
-     License as published by the Free Software Foundation; either
-     version 2.1 of the License, or (at your option) any later
-     version.
+     License as published by the Free Software Foundation, either
+     version 3 of the License, or (at your option) any later version.
 
      This library is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +13,8 @@
      Lesser General Public License for more details.
 
      You should have received a copy of the GNU Lesser General Public
-     License along with this library; if not, write to the Free
-     Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-     Boston, MA 02110-1301 USA
+     License along with This library.  If not, see
+     <http://www.gnu.org/licenses/>.
 */
 
 /** @page cmap_f_page Fortran API to CMAP 
@@ -227,8 +225,7 @@ static int SymopToFMat4(char *symchs_begin, char *symchs_end, float *rot)
   float sign = 1.0f, value = 0.0f, value2;
   char *cp, *ptr_symchs = symchs_begin, ch;
   int j,k;                                 /* loop variables */
-  unsigned char Isep = FALSE;                             /* parsed seperator? *
-/
+  unsigned char Isep = FALSE;		   /* parsed seperator? */
  
   /* initialise and clear the relevant */
   /* use knowledge that are using [4][4] for rot */
@@ -680,7 +677,7 @@ FORTRAN_SUBR( MRDHDS, mrdhds,
 
   ioArray[ii] = (IOConvMap *) malloc(sizeof(IOConvMap));
 
-  if ((ioArray[ii]->mapfile = ccp4_cmap_open(file, O_RDONLY)) == NULL) 
+  if ((ioArray[ii]->mapfile = ccp4_cmap_open(file, O_RDONLY)) == NULL) {
     if (!(*ifail)) {
       ccp4_signal(CCP4_ERRLEVEL(3) | CMAP_ERRNO(CMERR_CantOpenFile),
 		  "MRDHDS", NULL);
@@ -691,6 +688,7 @@ FORTRAN_SUBR( MRDHDS, mrdhds,
       *ifail = -1; 
       return ;
     }
+  }
   ioArray[ii]->ipc = *iunit;
   ioArray[ii]->logname = strdup(temp_map);
 
@@ -747,7 +745,7 @@ FORTRAN_SUBR( CCP4_MAP_READ_OPEN_HEADER_CHECK,
 
   ioArray[ii] = (IOConvMap *) malloc(sizeof(IOConvMap));
 
-  if ((ioArray[ii]->mapfile = ccp4_cmap_open(file, O_RDONLY)) == NULL) 
+  if ((ioArray[ii]->mapfile = ccp4_cmap_open(file, O_RDONLY)) == NULL) {
     if (!(*ifail)) {
       ccp4_signal(CCP4_ERRLEVEL(3) | CMAP_ERRNO(CMERR_CantOpenFile),
 		  "MRDHDS", NULL);
@@ -758,6 +756,7 @@ FORTRAN_SUBR( CCP4_MAP_READ_OPEN_HEADER_CHECK,
     *ifail = -1; 
     return;
     }
+  }
   ioArray[ii]->ipc = *iunit;
   ioArray[ii]->logname = strdup(temp_map);
 
@@ -1780,8 +1779,10 @@ FORTRAN_SUBR( MSYCPY, msycpy,
   int ii,jj, nsym, i;
   char symop[81];
 
-  if ( (ii = GetChannel(*iunit)) == MAXFILES || !ioArray[ii]->mapfile
-       || (jj = GetChannel(*ounit)) == MAXFILES || !ioArray[jj]->mapfile) 
+  ii = GetChannel(*iunit);
+  jj = GetChannel(*ounit);
+
+  if ( ii == MAXFILES || !ioArray[ii]->mapfile || jj  == MAXFILES || !ioArray[jj]->mapfile)
      ccp4_signal(CCP4_ERRLEVEL(4) | CMAP_ERRNO(CMERR_NoChannel),
 		 "MSYCPY", NULL);
 
@@ -1807,8 +1808,10 @@ FORTRAN_SUBR( CCP4_MAP_COPY_SYMMETRY,
   int ii,jj, nsym, i;
   char symop[81];
 
-  if ( (ii = GetChannel(*iunit)) == MAXFILES || !ioArray[ii]->mapfile
-       || (jj = GetChannel(*ounit)) == MAXFILES || !ioArray[jj]->mapfile) 
+  ii = GetChannel(*iunit);
+  jj = GetChannel(*ounit);
+
+  if ( ii == MAXFILES || !ioArray[ii]->mapfile || jj == MAXFILES || !ioArray[jj]->mapfile)
      ccp4_signal(CCP4_ERRLEVEL(4) | CMAP_ERRNO(CMERR_NoChannel),
 		 "MSYCPY", NULL);
 
