@@ -2,11 +2,10 @@
      cmtzlib_f.c: Fortran API to CMTZlib
      Copyright (C) 2001  CCLRC, Martyn Winn
 
-     This library is free software; you can redistribute it and/or
+     This library is free software: you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
-     License as published by the Free Software Foundation; either
-     version 2.1 of the License, or (at your option) any later
-     version.
+     License as published by the Free Software Foundation, either
+     version 3 of the License, or (at your option) any later version.
 
      This library is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +13,8 @@
      Lesser General Public License for more details.
 
      You should have received a copy of the GNU Lesser General Public
-     License along with this library; if not, write to the Free
-     Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-     Boston, MA 02110-1301 USA
+     License along with This library.  If not, see
+     <http://www.gnu.org/licenses/>.
 */
 
 /** @page cmtz_f_page Fortran API to CMTZ 
@@ -90,12 +88,12 @@ static char user_label_in[MFILES][MCOLUMNS][2][31];
 static char user_label_out[MFILES][MCOLUMNS][2][31];
 static MTZCOL *collookup[MFILES][MCOLUMNS];
 static MTZCOL *collookup_out[MFILES][MCOLUMNS];
-static int sortorder[MFILES][5] = {0};
+static int sortorder[MFILES][5] = {{0},{0},{0},{0},{0}};
 static int logmss[MFILES][MCOLUMNS];
 static int ndatmss[MFILES];
 static MTZBAT *rbat[MFILES];
 static int nbatw[MFILES] = {0};
-static double coefhkl[MFILES][6] = {0};
+static double coefhkl[MFILES][6] = {{0},{0},{0},{0},{0},{0}};
 
 /* MVS defaults to int and doesn't like it */
 #ifdef _MSC_VER
@@ -907,7 +905,7 @@ FORTRAN_SUBR ( LRIDX, lridx,
 		  int *isets, float *datcell, float *datwave,
                   int *ndatasets))
 {
-  int i,j,k,x,d,iset;
+  int j,k,x,d,iset;
   char cxname[64], cdname[64], cpname[64];
   int cisets;
   float cdatcell[6], cdatwave;
@@ -1032,7 +1030,7 @@ FORTRAN_SUBR ( LRIDC, lridc,
 		  int *isets, float *datcell, float *datwave,
                   int *ndatasets))
 {
-  int i,j,k,x,d,iset;
+  int j,k,x,d,iset;
   char cxname[64], cdname[64], cpname[64];
   int cisets;
   float cdatcell[6], cdatwave;
@@ -1092,7 +1090,7 @@ FORTRAN_SUBR ( LRID, lrid,
 		  fpstr dataset_name, int dataset_name_len,
 		  int *isets, int *ndatasets))
 {
-  int i,j,k,x,d,iset;
+  int j,k,x,d,iset;
   char cxname[64], cdname[64], cpname[64];
   int cisets;
   float cdatcell[6], cdatwave;
@@ -1199,7 +1197,7 @@ FORTRAN_SUBR ( LRREFF, lrreff,
 	       (const int *mindx, float *resol, float adata[], ftn_logical *eof),
 	       (const int *mindx, float *resol, float adata[], ftn_logical *eof))
 {
- int i,ieof,mcol,biomol,mindex;
+ int ieof,biomol,mindex;
 
   /*   CMTZLIB_DEBUG(puts("CMTZLIB_F: LRREFF");) */
 
@@ -1714,7 +1712,7 @@ FORTRAN_SUBR ( LWOPEN_NOEXIT, lwopen_noexit,
    for (i = 0; i < mtzdata[*mindx-1]->nxtal; ++i)
     for (j = 0; j < mtzdata[*mindx-1]->xtal[i]->nset; ++j)
      for (k = 0; k < mtzdata[*mindx-1]->xtal[i]->set[j]->ncol; ++k)
-       if (icol = mtzdata[*mindx-1]->xtal[i]->set[j]->col[k]->source)
+       if ( (icol = mtzdata[*mindx-1]->xtal[i]->set[j]->col[k]->source) )
          collookup_out[*mindx-1][icol-1] = mtzdata[*mindx-1]->xtal[i]->set[j]->col[k];
  }
 
@@ -2147,7 +2145,7 @@ FORTRAN_SUBR ( LWIDASX, lwidasx,
 	       (const int *mindx, int *nlprgo, fpstr xname, fpstr dname, int *iappnd),
 	       (const int *mindx, int *nlprgo, fpstr xname, int xname_len, 
                       fpstr dname, int dname_len, int *iappnd))
-{int i,j,k,istart;
+{int i,j,istart;
   char *crystal_name;
   char *dataset_name;
   MTZSET *baseset=NULL;
