@@ -2,11 +2,10 @@
      library_f.c: Fortran API to library.c
      Copyright (C) 2001  CCLRC, Charles Ballard
 
-     This library is free software; you can redistribute it and/or
+     This library is free software: you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
-     License as published by the Free Software Foundation; either
-     version 2.1 of the License, or (at your option) any later
-     version.
+     License as published by the Free Software Foundation, either
+     version 3 of the License, or (at your option) any later version.
 
      This library is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +13,8 @@
      Lesser General Public License for more details.
 
      You should have received a copy of the GNU Lesser General Public
-     License along with this library; if not, write to the Free
-     Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-     Boston, MA 02110-1301 USA
+     License along with This library.  If not, see
+     <http://www.gnu.org/licenses/>.
 */
 
 /** @file library_f.c
@@ -111,7 +109,7 @@ FORTRAN_SUBR ( USTENV, ustenv,
 
   temp_name = ccp4_FtoCString(FTN_STR(str), FTN_LEN(str));
 
-  if (*result = ccp4_utils_setenv (temp_name))  
+  if ( (*result = ccp4_utils_setenv (temp_name)) )
     ccp4_fatal("USTENV/CCP4_SETENV: Memory allocation failure"); 
   free(temp_name);
 }
@@ -222,7 +220,7 @@ FORTRAN_SUBR ( CCPAL1, ccpal1,
     (int) sizeof (int),            /* 5: not used */
     (int) sizeof (int)             /* 6: integers */
   };
-  int i, size, *leng[13];
+  int i, size = 0, *leng[13];
   void *pointer[13];
 
   for (i=0; i<*n; i++) {
