@@ -1,12 +1,13 @@
 /*
      load_syminfo.c: test program that loads syminfo.lib.
-     Copyright (C) 2007 Morten Kjeldgaard
 
-     This library is free software; you can redistribute it and/or
+     Copyright: © 2007 Morten Kjeldgaard <mok@bioxray.dk>
+     License: GPL-3+
+
+     This library is free software: you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
-     License as published by the Free Software Foundation; either
-     version 2.1 of the License, or (at your option) any later
-     version.
+     License as published by the Free Software Foundation, either
+     version 3 of the License, or (at your option) any later version.
 
      This library is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +15,8 @@
      Lesser General Public License for more details.
 
      You should have received a copy of the GNU Lesser General Public
-     License along with this library; if not, write to the Free
-     Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-     Boston, MA 02110-1301 USA
+     License along with This library.  If not, see
+     <http://www.gnu.org/licenses/>.
 
 */
 
@@ -24,7 +24,7 @@
 #include "ccp4_general.h"
 #include "ccp4_program.h"
 
-main ()
+int main ()
 {
   CCP4SPG *spg;
 
@@ -38,6 +38,8 @@ main ()
   ccp4spg_print_epsilon_zones(spg);
   ccp4spg_print_recip_spgrp(spg);
   ccp4spg_print_recip_ops(spg);
+
+  return 0;
 }
 
 
